@@ -7,12 +7,14 @@ from pandas.core.series import Series
 
 from ..graph.graph_object import Graph
 from ..query_runner.query_runner import QueryRunner
+from ..server_version.server_version import ServerVersion
 
 
 class Model(ABC):
-    def __init__(self, name: str, query_runner: QueryRunner):
+    def __init__(self, name: str, query_runner: QueryRunner, server_version: ServerVersion):
         self._name = name
         self._query_runner = query_runner
+        self._server_version = server_version
 
     @abstractmethod
     def _query_prefix(self) -> str:
@@ -66,11 +68,11 @@ class Model(ABC):
 
         return self._query_runner.run_query(query, params).squeeze()  # type: ignore
 
-    def drop(self) -> None:
-        query = "CALL gds.beta.model.drop($model_name)"
-        params = {"model_name": self._name}
+    def drop(self, failIfMissing: bool = False) -> Series:
+        query = "CALL gds.beta.model.drop($model_name, $fail_if_missing)"
+        params = {"model_name": self._name, "fail_if_missing": failIfMissing}
 
-        self._query_runner.run_query(query, params)
+        return self._query_runner.run_query(query, params).squeeze()  # type: ignore
 
     def metrics(self) -> Series:
         model_info = self._list_info()["modelInfo"][0]
@@ -81,7 +83,7 @@ class Model(ABC):
         config["modelName"] = self.name()
         params = {"graph_name": G.name(), "config": config}
 
-        return self._query_runner.run_query(query, params)
+        return self._query_runner.run_query_with_logging(query, params)
 
     def predict_stream_estimate(self, G: Graph, **config: Any) -> Series:
         return self._estimate_predict("stream", G.name(), config)
@@ -91,7 +93,7 @@ class Model(ABC):
         config["modelName"] = self.name()
         params = {"graph_name": G.name(), "config": config}
 
-        return self._query_runner.run_query(query, params).squeeze()  # type: ignore
+        return self._query_runner.run_query_with_logging(query, params).squeeze()  # type: ignore
 
     def predict_mutate_estimate(self, G: Graph, **config: Any) -> Series:
         return self._estimate_predict("mutate", G.name(), config)
