@@ -4,11 +4,11 @@ import pandas
 from pandas.core.series import Series
 
 from ..model.node_classification_model import NCModel
-from ..pipeline.training_pipeline import TrainingPipeline
+from ..pipeline.classification_training_pipeline import ClassificationTrainingPipeline
 from ..query_runner.query_runner import QueryRunner
 
 
-class NCTrainingPipeline(TrainingPipeline):
+class NCTrainingPipeline(ClassificationTrainingPipeline):
     def selectFeatures(self, node_properties: Union[str, List[str]]) -> Series:
         query = f"{self._query_prefix()}selectFeatures($pipeline_name, $node_properties)"
         params = {"pipeline_name": self.name(), "node_properties": node_properties}
@@ -23,4 +23,4 @@ class NCTrainingPipeline(TrainingPipeline):
         return "CALL gds.beta.pipeline.nodeClassification."
 
     def _create_trained_model(self, name: str, query_runner: QueryRunner) -> NCModel:
-        return NCModel(name, query_runner)
+        return NCModel(name, query_runner, self._server_version)
